BCI-Framework — BCI-Framework documentation

> Developed by Yeison Nolberto Cardona Álvarez
> Andrés Marino Álvarez Meza, PhD.
> César Germán Castellanos Dominguez, PhD.
> Digital Signal Processing and Control Group | Grupo de Control y Procesamiento Digital de Señales (GCPDS)
> National University of Colombia at Manizales | Universidad Nacional de Colombia sede Manizales

# BCI-Framework

A distributed processing tool, stimuli delivery, psychophysiological experiments designer and real-time data visualizations for OpenBCI.

BCI-Framework is an open-source tool for the acquisition of EEG/EMG/ECG signals, it is developed to work with OpenBCI’s Cyton board, the main core of this software lies on OpenBCI-Stream, a library that has been designed to handle all the low-level hardware features and extend the hardware capabilities with high-level programming libraries. An optionally distributed paradigm for data acquisition and streaming is available to be implemented, this approach stabilizes the sampling rate on non-real-time acquisition systems and consists on delegate the board handle to a dedicated environ and stream out the data in real-time. Write custom visualization for raw or processed time series and design custom neurophysiological experiments are the mayor features available in this application.

BCI-Framework consists of a graphical user interface (GUI) with a set of individual computational processes (distributed or in a single machine), that feed a visualization, serve a stimuli delivery, handle an acquisition, storage data, or stream a previous one (offline analysis). It has a built-in development environment and a set of libraries that can be implemented by the user to create their specific functionality.

## Screenshots